##### API Configurations

NDR Core's main functionality is to get data over an API and display it. In order to achieve this, you need to create a configuration on how to access your data. NDR Core provides multiple implementations of APIs. If your desired API is not in the list, you can write your own implementation.

###### Create a configuration

- The API Type defines the API implementation you will use.
- The API Name is the computer readable name of this API configuration. Forms are named with it. It can't contain special characters or spaces and must be unique within your installation. Choose a short descriptive name.
- The Displayable Label is the label displayed in the administration interface when you select API configurations for your search. More importantly it is displayed
- The Page Size is the number of results the API returns in per request.
- The Protocol specifies if the connection is over http or https.
- The API Host is ...
- The Port is ...
- The URL Stub is ...
- The Description is informational text for you or your team about this API configuration. It is not displayed outside of the administration interface.